@@ -60,13 +60,17 @@
  * F term_pulse_dtr - pulse the DTR line a device
  * F term_lower_dtr - lower the DTR line of a device
  * F term_raise_dtr - raise the DTR line of a device
+ * F term_lower_rts - lower the RTS line of a device
+ * F term_raise_rts - raise the RTS line of a device
  * F term_get_mctl - Get modem control signals status
  * F term_drain - drain the output from the terminal buffer
  * F term_flush - discard terminal input and output queue contents
+ * F term_fake_flush - discard terminal input and output queue contents
  * F term_break - generate a break condition on a device
  * F term_baud_up - return next higher baudrate
  * F term_baud_down - return next lower baudrate
  * F term_baud_ok - check if baudrate is valid
+ * F term_baud_std - check if baudrate is on of our listed standard baudrates
  * F term_strerror - return a string describing current error condition
  * F term_perror - print a string describing the current error condition
  * G term_errno - current error condition of the library
@@ -75,9 +79,10 @@
  * E flocntrl_t - library supported folw-control modes
  * M MAX_TERM - maximum number of fds that can be managed
  *
- * by Nick Patavalis (npat@inaccessnetworks.com)
+ * by Nick Patavalis (npat@efault.net)
  *
- * originaly by Pantelis Antoniou (panto@intranet.gr), Nick Patavalis
+ * originaly by Pantelis Antoniou (https://github.com/pantoniou),
+ *              Nick Patavalis
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -92,7 +97,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA 
+ * USA
  *
  * $Id: term.h,v 1.1 2003/05/07 18:00:05 npat Exp $
  */
@@ -120,29 +125,31 @@
  * See the error strings in "term.c" for a description of each.
  */
 enum term_errno_e {
-	TERM_EOK = 0,
-	TERM_ENOINIT,
-	TERM_EFULL,
+    TERM_EOK = 0,
+    TERM_ENOINIT,
+    TERM_EFULL,
     TERM_ENOTFOUND,
     TERM_EEXISTS,
     TERM_EATEXIT,
     TERM_EISATTY,
     TERM_EFLUSH,     /* see errno */
-	TERM_EGETATTR,   /* see errno */
-	TERM_ESETATTR,   /* see errno */
-	TERM_EBAUD,
-	TERM_ESETOSPEED,
-	TERM_ESETISPEED,
-	TERM_EGETSPEED,
-	TERM_EPARITY,
-	TERM_EDATABITS,
-	TERM_ESTOPBITS,
-	TERM_EFLOW,
-	TERM_EDTRDOWN,
-	TERM_EDTRUP,
-	TERM_EMCTL,
-	TERM_EDRAIN,     /* see errno */
-	TERM_EBREAK
+    TERM_EGETATTR,   /* see errno */
+    TERM_ESETATTR,   /* see errno */
+    TERM_EBAUD,
+    TERM_ESETOSPEED,
+    TERM_ESETISPEED,
+    TERM_EGETSPEED,
+    TERM_EPARITY,
+    TERM_EDATABITS,
+    TERM_ESTOPBITS,
+    TERM_EFLOW,
+    TERM_EDTRDOWN,
+    TERM_EDTRUP,
+    TERM_EMCTL,
+    TERM_EDRAIN,     /* see errno */
+    TERM_EBREAK,
+    TERM_ERTSDOWN,
+    TERM_ERTSUP
 };
 
 /* E parity_e
@@ -156,32 +163,32 @@ enum term_errno_e {
  * P_SPACE - space parity (parity bit always 0)
  */
 enum parity_e {
-	P_NONE = 0, 
-	P_EVEN, 
-	P_ODD,
-	P_MARK,
-	P_SPACE
+    P_NONE = 0,
+    P_EVEN,
+    P_ODD,
+    P_MARK,
+    P_SPACE
 };
 
-/* 
+/*
  * E flowcntrl_e
  *
  * Flow control modes, supported by the library.
  *
  * FC_NONE - no flow control
- * FC_RTSCTS - RTS/CTS handshaking, also known as hardware 
+ * FC_RTSCTS - RTS/CTS handshaking, also known as hardware
  *     flow-control.
- * FC_XONXOFF  - xon/xoff flow control. 
+ * FC_XONXOFF  - xon/xoff flow control.
  */
 enum flowcntrl_e {
-	FC_NONE = 0, 
-	FC_RTSCTS, 
-	FC_XONXOFF,
-	FC_OTHER
+    FC_NONE = 0,
+    FC_RTSCTS,
+    FC_XONXOFF,
+    FC_OTHER
 };
 
-/* 
- * C MCTL_xxx 
+/*
+ * C MCTL_xxx
  *
  * Modem control line bits. Used against the return value of
  * term_get_mctl().
@@ -225,7 +232,7 @@ const char *term_strerror (int terrnum, int errnum);
  * Emit a description of the current library (and possibly system)
  * error condition to the standard-error stream. The description is
  * prefixed by a user-supplied string. What is actually emmited is:
- * 
+ *
  *     <prefix><space><description>\n
  *
  * The description emitted is the string returned by term_strerror().
@@ -315,7 +322,7 @@ int term_erase (int fd);
 int term_replace (int oldfd, int newfd);
 
 /*
- * F term_apply 
+ * F term_apply
  *
  * Applies the settings stored in the "nexttermios" structure
  * associated with the managed filedes "fd", to the respective
@@ -334,7 +341,7 @@ int term_replace (int oldfd, int newfd);
 int term_apply (int fd, int now);
 
 /*
- * F term_revert 
+ * F term_revert
  *
  * Discards all the changes made to the nexttermios structure
  * associated with the managed filedes "fd" that have not been applied
@@ -361,7 +368,7 @@ int term_revert (int fd);
 int term_reset (int fd);
 
 /*
- * F term_refresh 
+ * F term_refresh
  *
  * Updates the contents of the currtermios structure associated with
  * the managed filedes "fd", by reading the settings from the
@@ -373,11 +380,11 @@ int term_reset (int fd);
 int term_refresh (int fd);
 
 /* F term_set_raw
- * 
+ *
  * Sets the "nexttermios" structure associated with the managed
  * filedes "fd" to raw mode. The effective settings of the device are
  * not affected by this function.
- * 
+ *
  * Returns negative on failure, non-negative on success. Returns
  * failure only to indicate invalid arguments, so the return value can
  * be safely ignored.
@@ -388,7 +395,7 @@ int term_refresh (int fd);
  * terminal settings as indicated:
  *
  *   -ignbrk -brkint -parmrk -istrip -inlcr -igncr -icrnl -ixon
- *   -opost -echo -echonl -icannon -isig -iexten -csize -parenb 
+ *   -opost -echo -echonl -icannon -isig -iexten -csize -parenb
  *   cs8 min=1 time=0
  */
 int term_set_raw (int fd);
@@ -423,7 +430,7 @@ int term_set_baudrate (int fd, int baudrate);
 int term_set_parity (int fd, enum parity_e parity);
 
 /* F term_set_databits
- * 
+ *
  * Sets the databits number in the "nexttermios" structure associated
  * with the managed filedes "fd" to "databits". The effective settings
  * of the device are not affected by this function.
@@ -437,7 +444,7 @@ int term_set_parity (int fd, enum parity_e parity);
 int term_set_databits (int fd, int databits);
 
 /* F term_set_stopbits
- * 
+ *
  * Sets the stopbits number in the "nexttermios" structure associated
  * with the managed filedes "fd" to "stopbits". The effective settings
  * of the device are not affected by this function.
@@ -455,7 +462,7 @@ int term_set_stopbits (int fd, int stopbits);
  * Sets the folwcontrol mode in the "nexttermios" structure associated
  * with the managed filedes "fd" to "flowcntl". The effective settings
  * of the device are not affected by this function.
- * 
+ *
  * The following flow control modes are supportd by the library:
  * FC_NONE, FC_RTSCTS, FC_XONXOFF.
  *
@@ -474,7 +481,7 @@ int term_set_flowcntrl (int fd, enum flowcntrl_e flowcntl);
  *
  * Returns negative on failure, non negative on success. Returns
  * failure only to indicate invalid arguments, so the return value can
- * be safely ignored. 
+ * be safely ignored.
  */
 int term_set_hupcl (int fd, int on);
 
@@ -487,7 +494,7 @@ int term_set_hupcl (int fd, int on);
  *
  * Returns negative on failure, non negative on success. Returns
  * failure only to indicate invalid arguments, so the return value can
- * be safely ignored. 
+ * be safely ignored.
  */
 int term_set_local (int fd, int local);
 
@@ -497,11 +504,11 @@ int term_set_local (int fd, int local);
  * associated with the managed filedes "fd". Actually sets the
  * following:
  *
- *   Raw mode if "raw" is nonzero. 
- *   Baudrate to "baud". 
- *   Parity mode to "parity". 
- *   Flow control mode to "fc". 
- *   Enables local mode if "local" is nonzero, dis. otherwise. 
+ *   Raw mode if "raw" is nonzero.
+ *   Baudrate to "baud".
+ *   Parity mode to "parity".
+ *   Flow control mode to "fc".
+ *   Enables local mode if "local" is nonzero, dis. otherwise.
  *   Enables HUP-on-close if "hupcl" is nonzero, dis. otherwise
  *
  * The effective settings of the device are not affected by this
@@ -516,13 +523,13 @@ int term_set_local (int fd, int local);
  * filedes to the framework, and following this it fails, then it will
  * remove the filedes before returning.
  */
-int term_set (int fd, 
-              int raw, 
-              int baud, 
-              enum parity_e parity, 
-			  int databits, int stopbits, 
-			  enum flowcntrl_e fc,
-			  int local, int hupcl);
+int term_set (int fd,
+              int raw,
+              int baud,
+              enum parity_e parity,
+              int databits, int stopbits,
+              enum flowcntrl_e fc,
+              int local, int hupcl);
 
 /* F term_get_baudrate
  *
@@ -605,6 +612,24 @@ int term_lower_dtr (int fd);
  */
 int term_raise_dtr (int fd);
 
+/* F term_lower_rts
+ *
+ * Lowers the RTS line of the device associated with the managed
+ * filedes "fd".
+ *
+ * Returns negative on failure, non negative on success.
+ */
+int term_lower_rts (int fd);
+
+/* F term_raise_rts
+ *
+ * Raises the RTS line of the device associated with the managed
+ * filedes "fd".
+ *
+ * Returns negative on failure, non negative on success.
+ */
+int term_raise_rts (int fd);
+
 /* F term_get_mctl
  *
  * Get the status of the modem control lines of the serial port
@@ -616,7 +641,7 @@ int term_raise_dtr (int fd);
  */
 int term_get_mctl (int fd);
 
-/* F term_drain 
+/* F term_drain
  *
  * Drains (flushes) the output queue of the device associated with the
  * managed filedes "fd". This functions blocks until all the contents
@@ -627,7 +652,7 @@ int term_get_mctl (int fd);
 int term_drain (int fd);
 
 /* F term_flush
- * 
+ *
  * Discards all the contents of the input AND output queues of the
  * device associated with the managed filedes "fd". Although it is
  * called flush this functions does NOT FLUSHES the terminal
@@ -638,6 +663,17 @@ int term_drain (int fd);
  */
 int term_flush (int fd);
 
+/* F term_fake_flush
+ *
+ * Fake a term_flush, by temporarily configuring the device associated
+ * with the managed fd to no flow-control and waiting until its output
+ * queue drains.
+ *
+ * Returns negative on failure, non-negative on success.
+ */
+int term_fake_flush(int fd);
+
+
 /* F term_break
  *
  * This function generates a break condition on the device associated
@@ -672,6 +708,12 @@ int term_baud_down (int baud);
  */
 int term_baud_ok(int baud);
 
+/* F term_baud_std
+ *
+ * Returns non-zero if "baud" is a standard baudrate, zero otherwise.
+ */
+int term_baud_std(int baud);
+
 /***************************************************************************/
 
 #endif /* of TERM_H */
